# kipoi_interpret
> Model interepretation plugin for Kipoi.

[![CircleCI](https://circleci.com/gh/kipoi/kipoi-interpret.svg?style=svg)](https://circleci.com/gh/kipoi/kipoi-interpret)
[![Coverage Status](https://coveralls.io/repos/github/kipoi/kipoi-interpret/badge.svg?branch=master)](https://coveralls.io/github/kipoi/kipoi-interpret?branch=master)

## Installation

```sh
pip install kipoi_interpret
```

## Usage example

 few motivating and useful examples of how your product can be used. Spice this up with code blocks and potentially more screenshots.

_For more examples and usage, please refer to the docs._

## Development setup

Describe how to install all development dependencies and how to run an automated test-suite of some kind. Potentially do this for multiple platforms.

```sh
TODO
```


## Release History

* 0.1.0
    * First release to PyPI
